@@ -11,7 +11,7 @@
 
 #include "abstractindexer.h"
 
-#include <Akonadi/KMime/MessageStatus>
+#include <Akonadi/MessageStatus>
 #include <KMime/Message>
 
 class EmailIndexer : public AbstractIndexer
@@ -24,7 +24,7 @@ public:
     EmailIndexer(const QString &path, const QString &contactDbPath);
     ~EmailIndexer() override;
 
-    QStringList mimeTypes() const override;
+    Q_REQUIRED_RESULT QStringList mimeTypes() const override;
 
     void index(const Akonadi::Item &item) override;
     void updateFlags(const Akonadi::Item &item, const QSet<QByteArray> &added, const QSet<QByteArray> &removed) override;
